#pragma region Globale Variablen
// Header-Datei fr die Windowsfunktionen
#include <windows.h>

HWND hWnd;	// Das Alias zum Fenster
#pragma endregion

#pragma region Callbackfunktion: Auswerten der Fensternachrichten
// Unsere Callback-Funktion zum Auswerten der Fensternachrichten
LRESULT CALLBACK WndProc(HWND hWnd /* Das Fenster */, UINT Msg /* Die Nachricht */,
						 WPARAM wParam, LPARAM lParam) // Jeweils Eingabewerte
{
	// Wenn eine Beendigungsnachricht kommt beenden:
	if(Msg == WM_DESTROY) { PostQuitMessage(0); return 0; }
	
	// Wenn ESC gedrckt wurde, Anwendung auch verlassen:
	if(Msg == WM_KEYDOWN && wParam == VK_ESCAPE) { PostQuitMessage(0); return 0; }

	// Andernfalls Nachricht einfach verarbeiten:
	return DefWindowProc(hWnd, Msg, wParam, lParam);
}
#pragma endregion

#pragma region Funktion: Ein Fenster erstellen
bool AssignApplicationAndCreateWindow(HINSTANCE hInstance)
{
	// WNDCLASS-Struktur fr die Applikationsbeschreibung fr Windows fllen
	WNDCLASS wc = {0}; // << Auch gleich mit 0 vorinitialisieren
	wc.hbrBackground = HBRUSH(GetStockObject(BLACK_BRUSH));	// Schwarzer Hintergrund
	wc.hCursor = LoadCursor(NULL, IDC_ARROW);				// Normaler Cursor
	wc.hIcon = LoadIcon(NULL, IDC_ARROW);					// Anwendungsicon
	wc.hInstance = hInstance;							// Alias der Anwnedung bergeben
	wc.lpfnWndProc = WndProc;							// Unsere Callback-Funktion
	wc.lpszClassName = L"MyZFXApp";						// Identifikationsname
	wc.style = CS_HREDRAW|CS_VREDRAW;					// Anwendungsstil
	// Nun Applikation registrieren
	RegisterClass(&wc);	

	// Das Fenster erstellen
	if(NULL==(hWnd = CreateWindowEx(NULL /* Kein Stil */,
									wc.lpszClassName /* Der Identifikationsname */,
									L"ZFX Tutorial Application" /* Fenstertitel */,
									WS_VISIBLE|WS_POPUP /* Aussehen des Fensters */,
									0, 0,
									GetSystemMetrics(0) /* X-Auflsung des Users */,
									GetSystemMetrics(1) /* Y-Auflsung des Users */,
									NULL,		// Ist von keinem Fenster abhngig
									NULL,		// Kein Men
									hInstance,	// Anwendungsalias
									NULL)))		// Initialnachricht an das Elternfenster
		return false;

	return true;
}
#pragma endregion

#pragma region Funktion: Eine Nachricht in der Hauptschleife verarbeiten
bool RunWindow()
{
	MSG msg = {0};
	// Nachricht verarbeiten, falls vorhanden
	if(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
	{
		// Wenn das Programm beendet werden soll, Hauptschleife verlassen
		if(msg.message == WM_QUIT) return false;

		// Nachricht verarbeiten
		DispatchMessage(&msg);
		TranslateMessage(&msg);
	}

	return true;
}
#pragma endregion

#pragma region Unsere Startfunktion
int WINAPI WinMain(HINSTANCE hInstance /* Unser Alias zur Anwendung */,
				   HINSTANCE hPrevInstance /* Ehemaliger Alias */,
				   LPSTR lpCmdLine /* Kommandozeile, wenn vorhanden */,
				   int nShowCmd /* Art, wie das Fenster gestartet werden soll */)
{
	// Fenster erstellen & Anwendung registrieren
	if(!AssignApplicationAndCreateWindow(hInstance)) return 0;

	// Die Hauptschleife
	while(RunWindow())
	{
		// Hier der Programmcode der Hauptschleife
	}

	// Programm verlassen
	return 0;
}

#pragma endregion